[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/peakrdl.svg)](https://pypi.org/project/peakrdl)

# PeakRDL

How exciting! Finally a command-line tool that unifies all the PeakRDL tools!

This is simply a placeholder for now as this is still in development.

Check this [issue thread for a summary of features](https://github.com/SystemRDL/PeakRDL/issues/1). Feel free to comment if you have ideas!
